# CHANGELOG


## v0.3.3 (2025-01-05)

### Bug Fixes

- Fix release for real this time
  ([`caaa9c9`](https://github.com/gtaylor/baymesh-cli/commit/caaa9c961570089a77f528889db14ce9cfdd1538))


## v0.3.2 (2025-01-05)

### Bug Fixes

- Fix release for real this time
  ([`eab6a5b`](https://github.com/gtaylor/baymesh-cli/commit/eab6a5b9d9de74bc0afec7bc84116f6101881ef9))


## v0.3.1 (2025-01-05)

### Bug Fixes

- Remove now-unused release.yml
  ([`7ed0adc`](https://github.com/gtaylor/baymesh-cli/commit/7ed0adca911258a5693af43e57eab24f73395276))


## v0.3.0 (2025-01-05)

### Features

- Attempt release automation fix
  ([`2ead208`](https://github.com/gtaylor/baymesh-cli/commit/2ead2082f217634a73445463f5fd918032370a32))


## v0.2.0 (2025-01-05)

### Features

- Attempt release automation fix
  ([`bb18bf7`](https://github.com/gtaylor/baymesh-cli/commit/bb18bf73cdadee6f3f83273460b772d950a6f2a5))


## v0.1.0 (2025-01-05)

### Documentation

- Add dev setup to README.md
  ([`3b72ec4`](https://github.com/gtaylor/baymesh-cli/commit/3b72ec4284b901d50b216ef75ac047283e72ebd3))

### Features

- Graduating to alpha
  ([`5015cfc`](https://github.com/gtaylor/baymesh-cli/commit/5015cfcf65d473e4a52a4173f475a6aa797b2649))


## v0.0.0 (2025-01-05)
